@@ -19,10 +19,14 @@ except ImportError:
 import bs4
 import string
 
+import iso8601
 from muranodashboard.dynamic_ui import yaql_expression
+import pytz
 import six
 import yaql
 
+from horizon.utils import functions as utils
+
 # WrappingColumn is only available in N-horizon
 # This make murano-dashboard compatible with Mitaka-horizon
 try:
@@ -32,7 +36,7 @@ except ImportError:
 
 
 def parse_api_error(api_error_html):
-    error_html = bs4.BeautifulSoup(api_error_html)
+    error_html = bs4.BeautifulSoup(api_error_html, "html.parser")
     body = error_html.find('body')
     if (not body or not body.text):
         return None
@@ -47,6 +51,12 @@ def ensure_python_obj(obj):
     return mappings.get(obj, obj)
 
 
+def adjust_datestr(request, datestr):
+    tz = pytz.timezone(utils.get_timezone(request))
+    dt = iso8601.parse_date(datestr).astimezone(tz)
+    return dt.strftime('%Y-%m-%d %H:%M:%S')
+
+
 class Bunch(object):
     """Bunch dict/object-like container.
 
