@@ -11,31 +11,22 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import horizon
+
+from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
-from muranodashboard import exceptions
-# prevent pyflakes from fail
-assert exceptions
+import horizon
+
+# Load the api rest services into Horizon
+import muranodashboard.api.rest  # noqa
 
 
-class DeployPanels(horizon.PanelGroup):
-    slug = 'deployment_group'
-    name = _('Deployment')
-    panels = ('environments',)
-
-
-class ManagePanels(horizon.PanelGroup):
-    slug = 'manage_metadata'
-    name = _('Manage')
-    panels = ('images', 'service_catalog')
-
-
-class Murano(horizon.Dashboard):
-    name = _('Murano')
-    slug = 'murano'
-    panels = (DeployPanels, ManagePanels)
-    default_panel = 'environments'
+class AppCatalog(horizon.Dashboard):
+    name = getattr(settings, 'MURANO_DASHBOARD_NAME', _("App Catalog"))
+    slug = "app-catalog"
+    default_panel = "environments"
     supports_tenants = True
 
-
-horizon.register(Murano)
+try:
+    horizon.base.Horizon.registered('app-catalog')
+except horizon.base.NotRegistered:
+    horizon.register(AppCatalog)
