@@ -39,6 +39,7 @@ from yaql import legacy
 
 from muranodashboard.api import packages as pkg_api
 from muranodashboard.common import net
+from muranodashboard.dynamic_ui import helpers
 from muranodashboard.environments import api as env_api
 
 
@@ -106,13 +107,14 @@ def wrap_regex_validator(validator, message):
     return _validator
 
 
-def get_murano_images(request):
+def get_murano_images(request, region=None):
     images = []
     try:
         # https://bugs.launchpad.net/murano/+bug/1339261 - glance
         # client version change alters the API. Other tuple values
         # are _more and _prev (in recent glance client)
-        images = glance.image_list_detailed(request)[0]
+        with helpers.current_region(request, region):
+            images = glance.image_list_detailed(request)[0]
     except Exception:
         LOG.error("Error to request image list from glance ")
         exceptions.handle(request, _("Unable to retrieve public images."))
@@ -348,29 +350,38 @@ class ChoiceField(forms.ChoiceField, CustomPropertiesField):
             if isinstance(choices, dict):
                 choices = list(choices.items())
             kwargs['choices'] = choices
-        kwargs['widget'] = hz_forms.ThemableSelectWidget(transform=_get_title)
         super(ChoiceField, self).__init__(**kwargs)
 
 
-class DynamicChoiceField(hz_forms.ThemableDynamicChoiceField,
-                         CustomPropertiesField):
+class DynamicChoiceField(hz_forms.DynamicChoiceField, CustomPropertiesField):
     pass
 
 
+class FlavorWidget(widgets.Select):
+    def __init__(self, *args, **kwargs):
+        super(FlavorWidget, self).__init__(*args, **kwargs)
+        self.attrs['class'] = self.attrs.get('class', '') + ' flavor'
+        self.attrs['id'] = 'id_flavor'
+
+
 class FlavorChoiceField(ChoiceField):
+    widget = FlavorWidget
+
     def __init__(self, *args, **kwargs):
         if 'requirements' in kwargs:
             self.requirements = kwargs.pop('requirements')
         super(FlavorChoiceField, self).__init__(*args, **kwargs)
 
     @with_request
-    def update(self, request, **kwargs):
+    def update(self, request, form=None, **kwargs):
         choices = []
-        flavors = nova.novaclient(request).flavors.list()
+        with helpers.current_region(request,
+                                    getattr(form, 'region', None)):
+            flavors = nova.novaclient(request).flavors.list()
 
         # If no requirements are present, return all the flavors.
         if not hasattr(self, 'requirements'):
-            choices = [(flavor.name, flavor.name) for flavor in flavors]
+            choices = [(flavor.id, flavor.name) for flavor in flavors]
         else:
             for flavor in flavors:
                 # If a flavor doesn't meet a minimum requirement,
@@ -391,7 +402,7 @@ class FlavorChoiceField(ChoiceField):
                 if 'max_memory_mb' in self.requirements:
                     if flavor.ram > self.requirements['max_memory_mb']:
                         continue
-                choices.append((flavor.name, flavor.name))
+                choices.append((flavor.id, flavor.name))
 
         choices.sort(key=lambda e: e[1])
         self.choices = choices
@@ -403,20 +414,27 @@ class FlavorChoiceField(ChoiceField):
             self.initial = kwargs["form"]["flavor"].value()
         else:
             # Search through selected flavors
-            for flavor_name, flavor_name in self.choices:
+            for flavor_id, flavor_name in self.choices:
                 if 'medium' in flavor_name:
-                    self.initial = flavor_name
+                    self.initial = flavor_id
                     break
 
+    def clean(self, value):
+        for flavor_id, flavor_name in self.choices:
+            if flavor_id == value:
+                return flavor_name
+        return value
+
 
 class KeyPairChoiceField(DynamicChoiceField):
     """This widget allows to select keypair for VMs"""
     @with_request
-    def update(self, request, **kwargs):
+    def update(self, request, form=None, **kwargs):
         self.choices = [('', _('No keypair'))]
-        for keypair in sorted(
-                nova.novaclient(request).keypairs.list(),
-                key=lambda e: e.name):
+        with helpers.current_region(request,
+                                    getattr(form, 'region', None)):
+            keypairs = nova.novaclient(request).keypairs.list()
+        for keypair in sorted(keypairs, key=lambda e: e.name):
             self.choices.append((keypair.name, keypair.name))
 
 
@@ -444,18 +462,18 @@ class Choice(object):
 
 
 class ImageChoiceField(ChoiceField):
-    widget = hz_forms.ThemableSelectWidget(
-        transform=_get_title,
-        transform_html_attrs=_disable_non_ready)
+    widget = hz_forms.SelectWidget(transform=_get_title,
+                                   transform_html_attrs=_disable_non_ready)
 
     def __init__(self, *args, **kwargs):
         self.image_type = kwargs.pop('image_type', None)
         super(ImageChoiceField, self).__init__(*args, **kwargs)
 
     @with_request
-    def update(self, request, **kwargs):
+    def update(self, request, form=None, **kwargs):
         image_map, image_choices = {}, []
-        murano_images = get_murano_images(request)
+        murano_images = get_murano_images(
+            request, getattr(form, 'region', None))
         for image in murano_images:
             murano_data = image.murano_property
             title = murano_data.get('title', image.name)
@@ -531,10 +549,12 @@ class NetworkChoiceField(ChoiceField):
 
 class AZoneChoiceField(ChoiceField):
     @with_request
-    def update(self, request, **kwargs):
+    def update(self, request, form=None, **kwargs):
         try:
-            availability_zones = nova.novaclient(
-                request).availability_zones.list(detailed=False)
+            with helpers.current_region(request,
+                                        getattr(form, 'region', None)):
+                availability_zones = nova.novaclient(
+                    request).availability_zones.list(detailed=False)
         except Exception:
             availability_zones = []
             exceptions.handle(request,
@@ -551,9 +571,11 @@ class AZoneChoiceField(ChoiceField):
 
 class VolumeChoiceField(ChoiceField):
     def __init__(self,
+                 include_volumes=True,
                  include_snapshots=True,
                  *args,
                  **kwargs):
+        self.include_volumes = include_volumes
         self.include_snapshots = include_snapshots
         super(VolumeChoiceField, self).__init__(*args, **kwargs)
 
@@ -561,14 +583,16 @@ class VolumeChoiceField(ChoiceField):
     def update(self, request, **kwargs):
         """This widget allows selection of Volumes and Volume Snapshots"""
         available = {'status': cinder.VOLUME_STATE_AVAILABLE}
-        try:
-            choices = [(volume.id, volume.name)
-                       for volume in cinder.volume_list(request,
-                       search_opts=available)]
-        except Exception:
-            choices = []
-            exceptions.handle(request,
-                              _("Unable to retrieve volume list."))
+        choices = []
+
+        if self.include_volumes:
+            try:
+                choices.extend((volume.id, volume.name)
+                               for volume in cinder.volume_list(request,
+                               search_opts=available))
+            except Exception:
+                exceptions.handle(request,
+                                  _("Unable to retrieve volume list."))
 
         if self.include_snapshots:
             try:
