@@ -12,16 +12,24 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import contextlib
 import re
 import string
 import types
 import uuid
 
+import six
+
 from django.core import validators
 
 _LOCALIZABLE_KEYS = set(['label', 'help_text', 'error_messages'])
 
 
+class ObjectID(object):
+    def __init__(self):
+        self.object_id = str(uuid.uuid4())
+
+
 def is_localizable(keys):
     return set(keys).intersection(_LOCALIZABLE_KEYS)
 
@@ -47,7 +55,7 @@ def decamelize(name):
 
 def explode(_string):
     """Explodes a string into a list of one-character strings."""
-    if not _string or not isinstance(_string, basestring):
+    if not _string or not isinstance(_string, six.string_types):
         return _string
     else:
         return list(_string)
@@ -76,11 +84,11 @@ def recursive_apply(predicate, transformer, value, *args):
     def rec(val):
         if predicate(val, *args):
             return rec(transformer(val, *args))
-        elif isinstance(val, types.DictType):
-            return dict((rec(k), rec(v)) for (k, v) in val.iteritems())
-        elif isinstance(val, types.ListType):
+        elif isinstance(val, dict):
+            return dict((rec(k), rec(v)) for (k, v) in six.iteritems(val))
+        elif isinstance(val, list):
             return [rec(v) for v in val]
-        elif isinstance(val, types.TupleType):
+        elif isinstance(val, tuple):
             return tuple([rec(v) for v in val])
         elif isinstance(val, types.GeneratorType):
             return rec(val)
@@ -99,17 +107,19 @@ def evaluate(value, context):
 
 def insert_hidden_ids(application):
     def wrap(k, v):
-        if k == '?':
+        if k == '?' and isinstance(v, dict) and not isinstance(
+                v.get('id'), ObjectID):
             v['id'] = str(uuid.uuid4())
             return k, v
-        else:
-            return rec(k), rec(v)
+        return rec(k), rec(v)
 
     def rec(val):
-        if isinstance(val, types.DictType):
-            return dict(wrap(k, v) for k, v in val.iteritems())
-        elif isinstance(val, types.ListType):
+        if isinstance(val, dict):
+            return dict(wrap(k, v) for k, v in six.iteritems(val))
+        elif isinstance(val, list):
             return [rec(v) for v in val]
+        elif isinstance(val, ObjectID):
+            return val.object_id
         else:
             return val
 
@@ -123,7 +133,7 @@ def int2base(x, base):
     :param base: number base, max value is 36
     :return: integer converted to the specified base
     """
-    digs = string.digits + string.lowercase
+    digs = string.digits + string.ascii_lowercase
     if x < 0:
         sign = -1
     elif x == 0:
@@ -134,8 +144,30 @@ def int2base(x, base):
     digits = []
     while x:
         digits.append(digs[x % base])
-        x /= base
+        x //= base
     if sign < 0:
         digits.append('-')
     digits.reverse()
     return ''.join(digits)
+
+
+def to_str(text):
+    if not isinstance(text, str):
+        # unicode in python2
+        if isinstance(text, six.text_type):
+            text = text.encode('utf-8')
+        # bytes in python3
+        elif isinstance(text, six.binary_type):
+            text = text.decode('utf-8')
+    return text
+
+
+@contextlib.contextmanager
+def current_region(request, region):
+    orig_region = request.user.services_region
+    if region is not None:
+        request.user.services_region = region
+    try:
+        yield
+    finally:
+        request.user.services_region = orig_region
