@@ -13,7 +13,7 @@
 #    under the License.
 
 from django.utils.translation import ugettext_lazy as _
-
+from horizon import exceptions
 from oslo_log import log as logging
 import six
 
@@ -25,6 +25,9 @@ from muranodashboard.environments import consts
 from muranodashboard.environments import topology
 
 
+KEY_ERROR_TEMPLATE = _(
+    "Error fetching the environment. The page may be rendered incorrectly. "
+    "Reason: %s")
 LOG = logging.getLogger(__name__)
 
 
@@ -41,7 +44,7 @@ def get_status_messages_for_service(request, service_id, environment_id):
                 environment_id, deployment.id, service_id)
 
             for report in reports:
-                result += report.created.replace('T', ' ') + ' - ' + \
+                result += utils.adjust_datestr(request, report.created) + ' - ' + \
                     report.text + '\n'
     return result
 
@@ -180,13 +183,23 @@ def _update_env(env, request):
     deployments = deployments_list(request, env.id)
     if deployments:
         latest_deployment = deployments[0]
-        deployed_services = {service['?']['id'] for service in
-                             latest_deployment.description['services']}
+        try:
+            deployed_services = {service['?']['id'] for service in
+                                 latest_deployment.description['services']}
+        except KeyError as e:
+            deployed_services = set()
+            exceptions.handle_recoverable(
+                request, KEY_ERROR_TEMPLATE % e.message)
     else:
         deployed_services = set()
 
     if env.services:
-        current_services = {service['?']['id'] for service in env.services}
+        try:
+            current_services = {service['?']['id'] for service in env.services}
+        except KeyError as e:
+            current_services = set()
+            exceptions.handle_recoverable(
+                request, KEY_ERROR_TEMPLATE % e.message)
     else:
         current_services = set()
 
@@ -292,7 +305,12 @@ def services_list(request, environment_id):
 
     for service_item in environment.services or []:
         service_data = service_item
-        service_id = service_data['?']['id']
+        try:
+            service_id = service_data['?']['id']
+        except KeyError as e:
+            exceptions.handle_recoverable(
+                request, KEY_ERROR_TEMPLATE % e.message)
+            continue
 
         if service_id in reports and reports[service_id]:
             last_operation = strip(reports[service_id].text)
@@ -313,7 +331,12 @@ def services_list(request, environment_id):
             service_data['name'] = service_data['?']['name']
         if (consts.DASHBOARD_ATTRS_KEY not in service_data['?'] or
                 not service_data['?'][consts.DASHBOARD_ATTRS_KEY].get('name')):
-            fqn = service_data['?']['type']
+            try:
+                fqn = service_data['?']['type']
+            except KeyError as e:
+                exceptions.handle_recoverable(
+                    request, KEY_ERROR_TEMPLATE % e.message)
+                continue
             version = None
             if '/' in fqn:
                 version, fqn = fqn.split('/')[1].split('@')
@@ -335,8 +358,14 @@ def service_list_by_fqns(request, environment_id, fqns):
         return []
     services = services_list(request, environment_id)
     LOG.debug('Service::Instances::List')
-    return [service for service in services
-            if service['?']['type'].split('/')[0] in fqns]
+    try:
+        services = [service for service in services
+                    if service['?']['type'].split('/')[0] in fqns]
+    except KeyError as e:
+        services = []
+        exceptions.handle_recoverable(request, KEY_ERROR_TEMPLATE % e.message)
+
+    return services
 
 
 def service_create(request, environment_id, parameters):
@@ -361,9 +390,13 @@ def service_delete(request, environment_id, service_id):
 def service_get(request, environment_id, service_id):
     services = services_list(request, environment_id)
     LOG.debug("Return service detail for a specified id")
-    for service in services:
-        if service['?']['id'] == service_id:
-            return service
+    try:
+        for service in services:
+            if service['?']['id'] == service_id:
+                return service
+    except KeyError as e:
+        exceptions.handle_recoverable(request, KEY_ERROR_TEMPLATE % e.message)
+    return None
 
 
 def extract_actions_list(service):
@@ -389,6 +422,20 @@ def deployments_list(request, environment_id):
     return deployments
 
 
+def deployment_history(request):
+    LOG.debug('Deployment::History')
+    deployment_history = api.muranoclient(request).deployments.list(
+        None, all_environments=True)
+
+    for deployment in deployment_history:
+        reports = deployment_reports(request, deployment.environment_id,
+                                     deployment.id)
+        deployment.reports = reports
+
+    LOG.debug('Deployment::History {0}'.format(deployment_history))
+    return deployment_history
+
+
 def deployment_reports(request, environment_id, deployment_id):
     LOG.debug('Deployment::Reports::List')
     reports = api.muranoclient(request).deployments.reports(environment_id,
@@ -402,7 +449,7 @@ def get_deployment_start(request, environment_id, deployment_id):
     LOG.debug('Get deployment start time')
     for deployment in deployments:
         if deployment.id == deployment_id:
-            return deployment.started.replace('T', ' ')
+            return utils.adjust_datestr(request, deployment.started)
     return None
 
 
