@@ -14,6 +14,7 @@ import contextlib
 import json
 import logging
 import os
+import six
 import six.moves.urllib.parse as urlparse
 import testtools
 import time
@@ -93,17 +94,11 @@ class UITestCase(testtools.TestCase):
         self.driver.implicitly_wait(30)
         self.addOnException(self.take_screenshot)
         self.log_in()
-        self.projects_to_delete = []
         self.switch_to_project(cfg.common.tenant)
 
     def tearDown(self):
         super(UITestCase, self).tearDown()
 
-        self.switch_to_project(cfg.common.tenant)
-
-        for project_id in self.projects_to_delete:
-            self.keystone_client.projects.delete(project_id)
-
         for env in self.murano_client.environments.list():
             self.remove_environment(env.id)
 
@@ -163,13 +158,6 @@ class UITestCase(testtools.TestCase):
                      if tenant.name == name]
         return tenant_id[0]
 
-    def create_project(self, name):
-        project = self.keystone_client.projects.create(
-            name=name, domain="default", description="For Test Purposes",
-            enabled=True)
-        self.projects_to_delete.append(project.id)
-        return project.id
-
     def add_user_to_project(self, project_id, user_id, user_role=None):
         if not user_role:
             roles = self.keystone_client.roles.list()
@@ -226,9 +214,11 @@ class UITestCase(testtools.TestCase):
             by.By.XPATH, "//ul[contains(@class, 'navbar-right')]")
         user_menu.find_element(
             by.By.XPATH, ".//span[@class='user-name']").click()
-        user_menu.find_element(by.By.LINK_TEXT, 'Sign Out').click()
+        user_menu.find_element(by.By.PARTIAL_LINK_TEXT, 'Sign Out').click()
 
     def fill_field(self, by_find, field, value):
+        self.check_element_on_page(by_find, field)
+        self.wait_element_is_clickable(by_find, field)
         self.driver.find_element(by=by_find, value=field).clear()
         self.driver.find_element(by=by_find, value=field).send_keys(value)
 
@@ -435,12 +425,12 @@ class ImageTestCase(PackageBase):
     def setUpClass(cls):
         super(ImageTestCase, cls).setUpClass()
         glance_endpoint = cls.service_catalog.url_for(service_type='image')
-        cls.glance = gclient.Client('1', endpoint=glance_endpoint,
+        cls.glance = gclient.Client('2', endpoint=glance_endpoint,
                                     session=cls.keystone_client.session)
 
     def setUp(self):
         super(ImageTestCase, self).setUp()
-        self.image_title = self.gen_random_resource_name('test-image', 15)
+        self.image_title = self.gen_random_resource_name('default-image', 15)
         self.image = self.upload_image(self.image_title)
 
     def tearDown(self):
@@ -450,13 +440,14 @@ class ImageTestCase(PackageBase):
     @classmethod
     def upload_image(cls, title):
         try:
-            property = {'murano_image_info': json.dumps({'title': title,
-                                                         'type': 'linux'})}
+            murano_property = json.dumps({'title': title, 'type': 'linux'})
             image = cls.glance.images.create(name='TestImage',
                                              disk_format='qcow2',
-                                             size=0,
-                                             is_public=True,
-                                             properties=property)
+                                             container_format='bare',
+                                             is_public='True',
+                                             murano_image_info=murano_property)
+            image_data = six.BytesIO(None)
+            cls.glance.images.upload(image['id'], image_data)
         except Exception:
             logger.error("Unable to create or update image in Glance")
             raise
@@ -468,6 +459,23 @@ class ImageTestCase(PackageBase):
 
 
 class FieldsTestCase(PackageBase):
+    def check_js_error_message_is_present(self, error_message):
+        self.driver.implicitly_wait(2)
+        self.driver.find_element_by_xpath(
+            consts.JsErrorMessage.format(error_message))
+        self.driver.implicitly_wait(30)
+
+    def check_js_error_message_is_absent(self, error_message):
+        self.driver.implicitly_wait(2)
+        try:
+            self.driver.find_element_by_xpath(
+                consts.ErrorMessage.format(error_message))
+        except (exc.NoSuchElementException, exc.ElementNotVisibleException):
+            logger.info("Message {0} is not"
+                        " present on the page".format(error_message))
+
+        self.driver.implicitly_wait(30)
+
     def check_error_message_is_present(self, error_message):
         self.driver.find_element_by_xpath(consts.ButtonSubmit).click()
         self.driver.find_element_by_xpath(
@@ -558,14 +566,26 @@ class ApplicationTestCase(ImageTestCase):
                                        consts.InputSubmit).click()
         self.select_from_list('osImage', self.image.id)
 
-        self.wait_element_is_clickable(by.By.XPATH,
-                                       consts.InputSubmit).click()
         if env_id:
-            self.wait_element_is_clickable(by.By.XPATH,
-                                           consts.InputSubmit).click()
+            # If another app is added, then env_id is passed in. In this case,
+            # the 'Next' followed by 'Create' must be clicked.
+            self.check_element_on_page(by.By.CSS_SELECTOR,
+                                       consts.NextWizardSubmit)
+            self.wait_element_is_clickable(
+                by.By.CSS_SELECTOR, consts.NextWizardSubmit).click()
+            self.check_element_on_page(by.By.CSS_SELECTOR,
+                                       consts.CreateWizardSubmit)
+            self.wait_element_is_clickable(
+                by.By.CSS_SELECTOR, consts.CreateWizardSubmit).click()
+
             self.wait_element_is_clickable(by.By.ID, consts.AddComponent)
             self.check_element_on_page(by.By.LINK_TEXT, app_name)
         else:
+            # Otherwise, only 'Create' needs to be clicked.
+            self.check_element_on_page(by.By.CSS_SELECTOR,
+                                       consts.CreateWizardSubmit)
+            self.wait_element_is_clickable(
+                by.By.CSS_SELECTOR, consts.CreateWizardSubmit).click()
             self.wait_for_alert_message()
 
     def execute_action_from_table_view(self, env_name, table_action):
